==> tuia-news-center-api-0.0.55-xt-20180806.055500-1-sources.jar: cn/com/duiba/tuia/news/center/dto/Response/WechatServiceDto.java <==
package cn.com.duiba.tuia.news.center.dto.Response;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xiaotian on 2018/7/12.
 */
public class WechatServiceDto implements Serializable {
    private Long id;

    private String serviceName;

    private String serviceAppid;

    private String serviceAppsecret;

    private Integer serviceStatus;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getServiceName() {
        return serviceName;
    }

    public void setServiceName(String serviceName) {
        this.serviceName = serviceName == null ? null : serviceName.trim();
    }

    public String getServiceAppid() {
        return serviceAppid;
    }

    public void setServiceAppid(String serviceAppid) {
        this.serviceAppid = serviceAppid == null ? null : serviceAppid.trim();
    }

    public String getServiceAppsecret() {
        return serviceAppsecret;
    }

    public void setServiceAppsecret(String serviceAppsecret) {
        this.serviceAppsecret = serviceAppsecret == null ? null : serviceAppsecret.trim();
    }

    public Integer getServiceStatus() {
        return serviceStatus;
    }

    public void setServiceStatus(Integer serviceStatus) {
        this.serviceStatus = serviceStatus;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> tuia-news-center-api-2.0.0.0-xt-20190403.025840-1-sources.jar: cn/com/duiba/tuia/news/center/dto/Response/WechatServiceDto.java <==
package cn.com.duiba.tuia.news.center.dto.Response;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xiaotian on 2018/7/12.
 */
public class WechatServiceDto implements Serializable {
    private Long id;

    private String serviceName;

    private String serviceAppid;

    private String serviceAppsecret;

    private Integer serviceStatus;

    private Date gmtCreate;

    private Date gmtModified;
    /**
     * 服务版本  0:老   1：新
     */
    private Integer serviceVersion;

    public Integer getServiceVersion() {
        return serviceVersion;
    }

    public void setServiceVersion(Integer serviceVersion) {
        this.serviceVersion = serviceVersion;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getServiceName() {
        return serviceName;
    }

    public void setServiceName(String serviceName) {
        this.serviceName = serviceName == null ? null : serviceName.trim();
    }

    public String getServiceAppid() {
        return serviceAppid;
    }

    public void setServiceAppid(String serviceAppid) {
        this.serviceAppid = serviceAppid == null ? null : serviceAppid.trim();
    }

    public String getServiceAppsecret() {
        return serviceAppsecret;
    }

    public void setServiceAppsecret(String serviceAppsecret) {
        this.serviceAppsecret = serviceAppsecret == null ? null : serviceAppsecret.trim();
    }

    public Integer getServiceStatus() {
        return serviceStatus;
    }

    public void setServiceStatus(Integer serviceStatus) {
        this.serviceStatus = serviceStatus;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
